#!/usr/bin/python
#
# collect_results.py
# Gabriel M. Beddingfield
# 2008-02-10
#
# Collect test results into a sqlite database
#

import re
import sys
from pysqlite2 import dbapi2 as sqlite

##
## CONFIG
##

filenames = {
    'Natural': 'test_results_natural.txt',
    'Metronome': 'test_results_metronome_144.txt',
    'Sloppy': 'test_results_metronome_144_sloppy.txt'
    }

tests = { 'Natural': 1, 'Metronome': 2, 'Sloppy': 3 }
speeds = { 'slowly': 1, 'medium': 2, 'fast': 3 }
models = { 'Average': 1, 'LeastSquares': 2, 'Median': 3, 'AvgTempo': 4 }
taps = (3, 4, 5, 6)

metronome = 144.0  # beats per minute

##
## Slurp up the files into a great big database
##

conn = sqlite.connect('test_results.db')
cur = conn.cursor()

cur.execute('CREATE TABLE res ('
            ' beats  int, '
            ' speed_id  int, '
            ' test_id  int, '
            ' model_id  int, '
            ' interval  int, '
            ' delta  float '
            ')')

cur.execute('CREATE TABLE tests ('
            ' id int, '
            ' name text '
            ')')

cur.execute('CREATE TABLE speeds ('
            ' id int, '
            ' name text '
            ')')

cur.execute('CREATE TABLE models ('
            ' id int, '
            ' name text '
            ')')

for t in tests.keys():
    cur.execute('INSERT INTO tests (id, name) VALUES (?, ?)',
                (tests[t], t))

for t in speeds.keys():
    cur.execute('INSERT INTO speeds (id, name) VALUES (?, ?)',
                (speeds[t], t))

for t in models.keys():
    cur.execute('INSERT INTO models (id, name) VALUES (?, ?)',
                (models[t], t))

print "moving on..."

testline = re.compile(r'Please give (\d+) taps (.*)')
resultline = re.compile(r'TapTempo(.*): cpb = (\d+) next = \d+ diff = ([-\.\d]+) ms')

currtest = ''
currspeed = 0
currtaps = 0
currmodel = ''

for t in tests.keys():
    currtest = t
    fp = open(filenames[t], 'rt')
    for line in fp.readlines():
        mch = testline.match(line)
        if mch is not None:
            currtaps = mch.group(1)
            currspeed = mch.group(2)
            continue
        mch = resultline.match(line)
        if mch is not None:
            currmodel = mch.group(1)
            interval = mch.group(2)
            delta = mch.group(3)
            cur.execute( 'INSERT INTO res (beats, speed_id, test_id, model_id, interval, delta) '
                         ' VALUES (?, ?, ?, ?, ?, ?)',
                         (currtaps, speeds[currspeed], tests[currtest],
                          models[currmodel], interval, delta) )
    fp.close()

conn.commit()
conn.close()



