CREATE TEMPORARY TABLE beat_prediction (
    beats int,
    speed text,
    model text,
    Natural float default 0.0,
    Metronome float default 0.0,
    Sloppy float default 0.0,
    Total float
    );

INSERT INTO beat_prediction (beats, speed, model, Natural, Total)
  SELECT r.beats, s.name, m.name, abs(r.delta) as Natural, abs(r.delta) as Total
  FROM res as r, speeds as s, models as m
  WHERE r.test_id = 1
  AND r.speed_id = s.id
  AND r.model_id = m.id;
INSERT INTO beat_prediction (beats, speed, model, Metronome, Total)
  SELECT r.beats, s.name, m.name, abs(r.delta) as Metronome, abs(r.delta) as Total
  FROM res as r, speeds as s, models as m
  WHERE r.test_id = 2
  AND r.speed_id = s.id
  AND r.model_id = m.id;
INSERT INTO beat_prediction (beats, speed, model, Sloppy, Total)
  SELECT beats, s.name, m.name, abs(delta) as Sloppy, abs(delta) as Total
  FROM res as r, speeds as s, models as m
  WHERE r.test_id = 3
  AND r.speed_id = s.id
  AND r.model_id = m.id;

SELECT "Accuracy of Prediction by Beats";
.headers on
.mode column
.width 5, 8, 8, 8
SELECT beats, sum(Natural) as Natural,
       sum(Metronome) as Metronome,
       sum(Sloppy) as Sloppy,
       sum(Total) as Total
FROM beat_prediction
GROUP BY beats
ORDER BY beats;

.headers off
.mode list
SELECT '=====  ========  ========  ========  ========';
.mode column
SELECT 'all', sum(Natural), sum(Metronome), sum(Sloppy), sum(Total)
  FROM beat_prediction;

.mode list
SELECT '';

SELECT 'Average Accuracy of Predicition by Model';
.headers on
.mode column
SELECT model, sum(Natural)/36 as Natural,
       sum(Metronome)/36 as Metronome,
       sum(Sloppy)/36 as Sloppy,
       sum(Total)/108 as Total
  FROM beat_prediction
  GROUP BY model
  ORDER BY model;

.mode list
.headers off
SELECT '';

SELECT 'Accuracy of Prediction by Beat for Median';
.mode column
.headers on
SELECT beats, sum(Natural) as Natural,
       sum(Metronome) as Metronome,
       sum(Sloppy) as Sloppy,
       sum(Total) as Total
  FROM beat_prediction
  WHERE model = 'Median'
  GROUP BY beats
  ORDER BY beats;

.mode list
.headers off
SELECT '';

SELECT 'Accuracy of Prediction by Beat for Average';
.mode column
.headers on
SELECT beats, sum(Natural) as Natural,
       sum(Metronome) as Metronome,
       sum(Sloppy) as Sloppy,
       sum(Total) as Total
  FROM beat_prediction
  WHERE model = 'Average'
  GROUP BY beats
  ORDER BY beats;

.mode list
.headers off
SELECT '';

SELECT 'Accuracy of Prediction by Beat for LeastSquares';
.mode column
.headers on
SELECT beats, sum(Natural) as Natural,
       sum(Metronome) as Metronome,
       sum(Sloppy) as Sloppy,
       sum(Total) as Total
  FROM beat_prediction
  WHERE model = 'LeastSquares'
  GROUP BY beats
  ORDER BY beats;

.mode list
.headers off
SELECT '';

SELECT 'Accuracy of Prediction by Beat for AvgTempo';
.mode column
.headers on
SELECT beats, sum(Natural) as Natural,
       sum(Metronome) as Metronome,
       sum(Sloppy) as Sloppy,
       sum(Total) as Total
  FROM beat_prediction
  WHERE model = 'AvgTempo'
  GROUP BY beats
  ORDER BY beats;

.mode list
.headers off
SELECT '';

CREATE TEMPORARY TABLE interval_calc (
    beats int,
    speed text,
    model text,
    Metronome float default null,
    Sloppy float default null,
    Total float
    );

INSERT INTO interval_calc (beats, speed, model, Metronome, Total)
  SELECT r.beats, s.name, m.name, abs(r.interval) as Metronome, abs(r.interval) as Total
  FROM res as r, speeds as s, models as m, tests as t
  WHERE r.test_id = 2
  AND r.speed_id = s.id
  AND r.model_id = m.id;
INSERT INTO interval_calc (beats, speed, model, Sloppy, Total)
  SELECT beats, s.name, m.name, abs(interval) as Sloppy, abs(interval) as Total
  FROM res as r, speeds as s, models as m
  WHERE r.test_id = 3
  AND r.speed_id = s.id
  AND r.model_id = m.id;

UPDATE interval_calc
  SET Metronome = abs(1250001 - Metronome),
  Total = abs(1250001 - Metronome)
  WHERE speed = 'slowly' AND Metronome > 0;
UPDATE interval_calc
  SET Metronome = abs(833334 - Metronome),
  Total = abs(833334 - Metronome)
  WHERE speed = 'medium' AND Metronome > 0;
UPDATE interval_calc
  SET Metronome = abs(416667 - Metronome),
  Total = abs(416667 - Metronome)
  WHERE speed = 'fast' AND Metronome > 0;
UPDATE interval_calc
  SET Sloppy = abs(1250001 - Sloppy),
  Total = abs(1250001 - Sloppy)
  WHERE speed = 'slowly' AND Sloppy > 0;
UPDATE interval_calc
  SET Sloppy = abs(833334 - Sloppy),
  Total = abs(833334 - Sloppy)
  WHERE speed = 'medium' AND Sloppy > 0;
UPDATE interval_calc
  SET Sloppy = abs(416667 - Sloppy),
  Total = abs(416667 - Sloppy)
  WHERE speed = 'fast' and Sloppy > 0;



SELECT 'Average Accuracy of Interval Calculation by Model';
.mode column
.width 12, 12, 12, 12
.headers on
SELECT model, sum(Metronome)/36.0 as Metronome, sum(Sloppy)/36.0 as Sloppy
  FROM interval_calc
  GROUP BY model
  ORDER BY model;


